@@ -13,7 +13,7 @@
 #include "kget.h"
 
 #include "kget_debug.h"
-#include <qdebug.h>
+#include <QDebug>
 #include <KLocalizedString>
 #include <kuiserverjobtracker.h>
 
