@@ -28,19 +28,19 @@ class MetalinkXml : public AbstractMetalink
 
     public:
         MetalinkXml(TransferGroup * parent, TransferFactory * factory,
-                    Scheduler * scheduler, const KUrl & src, const KUrl & dest,
-                    const QDomElement * e = 0);
+                    Scheduler * scheduler, const QUrl & src, const QUrl & dest,
+                    const QDomElement * e = nullptr);
 
         ~MetalinkXml();
 
-        void save(const QDomElement &element);
-        void load(const QDomElement *e);
+        void save(const QDomElement &element) override;
+        void load(const QDomElement *e) override;
 
     public Q_SLOTS:
         // --- Job virtual functions ---
-        void start();
+        void start() override;
 
-        void deinit(Transfer::DeleteOptions options);
+        void deinit(Transfer::DeleteOptions options) override;
 
     protected Q_SLOTS:
         /**
@@ -48,19 +48,19 @@ class MetalinkXml : public AbstractMetalink
          * @note false does not mean that an error happened, it could mean, that the user
          * decided to update the metalink
          */
-        bool metalinkInit(const KUrl &url = KUrl(), const QByteArray &data = QByteArray());
+        bool metalinkInit(const QUrl &url = QUrl(), const QByteArray &data = QByteArray());
 
     protected :
         /**
          * @note downloads the metalink file, then starts the download
          */
         void downloadMetalink();
-        void startMetalink();
+        void startMetalink() override;
         void untickAllFiles();
 
     private:
         bool m_metalinkJustDownloaded;
-        KUrl m_localMetalinkLocation;
+        QUrl m_localMetalinkLocation;
         KGetMetalink::Metalink m_metalink;
 
 };
